SubscribeCommand

Enum SubscribeCommand 

pub enum SubscribeCommand {
Show 16 variants Data(SubscribeCustomData), Instrument(SubscribeInstrument), Instruments(SubscribeInstruments), BookDeltas(SubscribeBookDeltas), BookDepth(SubscribeBookDepth), BookSnapshots(SubscribeBookSnapshots), Quotes(SubscribeQuotes), Trades(SubscribeTrades), Bars(SubscribeBars), MarkPrices(SubscribeMarkPrices), IndexPrices(SubscribeIndexPrices), FundingRates(SubscribeFundingRates), InstrumentStatus(SubscribeInstrumentStatus), InstrumentClose(SubscribeInstrumentClose), OptionGreeks(SubscribeOptionGreeks), OptionChain(SubscribeOptionChain),
}

Variants

Implementations

Source

impl SubscribeCommand

pub fn as_any(&self) -> &dyn Any

Converts the command to a dyn Any trait object for messaging.

pub fn into_unsubscribe( self, command_id: UUID4, ts_init: UnixNanos, correlation_id: Option<UUID4>, ) -> UnsubscribeCommand

Converts this subscribe command into its matching unsubscribe command.

Preserves the subscribed data identity and client route while replacing the command ID and initialization timestamp. It also preserves parameters and sets the supplied correlation ID when the matching unsubscribe command supports those fields.

pub fn command_id(&self) -> UUID4

pub fn client_id(&self) -> Option<&ClientId>

pub fn venue(&self) -> Option<&Venue>

pub fn ts_init(&self) -> UnixNanos

pub fn correlation_id(&self) -> Option<UUID4>

pub fn params(&self) -> Option<&Params>